import pymysql


# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate MySQL Database                                         #
# ---------------------------------------------------------------------------------------------------------------------#

####--------------------------------------- MySQL Database Functions -----------------------------------------------####


def open_mysql_connection(host, port, username, password, database):
    try:
        db_con = pymysql.connect(host=host, port=port, user=username, passwd=password, db=database,
                                 cursorclass=pymysql.cursors.DictCursor, autocommit=True)
    except Exception:
        print("Error in MySQL connection with " + database + " database.")
    else:
        return db_con


def get_columns_from_dict(source, args_key):
    """Convert a dict of arguments into a string to columns separate by comma. Example: 'column_1, column_2,
    column_3'. """
    str_columns = ""
    data_args = source.get(args_key.replace(' ', '_'))
    if data_args is not None:
        for key, value in enumerate(data_args[0]):
            str_columns += value + ', '
    else:
        message = "No matching results for parameter data = " + args_key + " was found in DataPool."
        raise Exception(message)
    return str_columns[:-2]


def execute_query(db_connection, sql_query):
    connection = db_connection
    try:
        with connection.cursor() as cursor:
            cursor.execute(sql_query)
            result = cursor.fetchall()
            connection.commit()
    finally:
        connection.close()
    return result


def get_entire_result_from_executed_query(host, port, username, password, database, sql_query):
    connection = open_mysql_connection(host, port, username, password, database)
    try:
        with connection.cursor() as cursor:
            cursor.execute(sql_query)
            result = cursor.fetchall()
            connection.commit()
    finally:
        connection.close()
    return result


def execute_query_from_db(host, port, username, password, database, sql_query):
    connection = open_mysql_connection(host, port, username, password, database)
    try:
        with connection.cursor() as cursor:
            cursor.execute(sql_query)
            result = cursor.fetchall()
            connection.commit()
    finally:
        connection.close()
    return result


def select_all_from_table(db_connection, table):
    con = db_connection
    sql_query = "SELECT * FROM " + table
    con.execute(sql_query)
    return con.fetchall()


def close_connection_database(db_connection):
    con = db_connection
    con.close()



import json
import jinja2


# ---------------------------------------------------------------------------------------------------------------------#
#                    Functions to manipulate JSON files information and responses                                      #
# ---------------------------------------------------------------------------------------------------------------------#

# ------------------------------------------------- JSON Functions ----------------------------------------------------#


def load_json_as_string(json_file_path):
    json_file = json_file_path
    with open(json_file, 'r') as file:
        json_data = json.loads(file)
        return json_data


def load_json_as_dict(json_file_path):
    json_file = json_file_path
    with open(json_file, 'r') as file:
        json_data = json.load(file)
        return json_data


def get_json_keys(json_file_path):
    json_file = load_json_as_dict(json_file_path)
    return json_file.keys()


def get_json_values(json_file_path):
    json_file = load_json_as_dict(json_file_path)
    return json_file.values()


def write_json_file(json_string):
    new_json = json.dumps(json_string, sort_keys=True)
    open("new_json.json", "w").write(new_json)


def find_key_and_replace_value_json(obj, key, value):
    if key in obj:
        obj[key] = value
        return obj[key]
    if type(obj) is str:
        json.dumps(obj, indent=2, sort_keys=True)
    if type(obj) is dict:
        for k, v in obj.items():
            if isinstance(v, dict):
                item = find_key_and_replace_value_json(v, key, value)
                if item is not None:
                    return json.dumps(obj, indent=2, sort_keys=True)
    elif type(obj) is list:
        for k, v in enumerate(obj):
            item = find_key_and_replace_value_json(v, key, value)
            if item is not None:
                return json.dumps(obj, indent=2, sort_keys=True)


def convert_to_dict(data):
    converted_data = None
    if type(data) is list:
        for index, item in enumerate(data):
            # Convert to dict
            converted_data = eval(data[index])
            # Load json file
    elif type(data) is dict:
        converted_data = data
    else:
        print("\nType is different from 'list' or 'dict'")
    return converted_data


def edit_json(json_data, args):
    new_json = []
    for args_key, args_value in args.items():
        for key, value in json_data.items():
            if args_key == key and args_value != value:
                json_data[key] = args_value
            else:
                new_json_data = json_data[key]
                if (type(new_json_data) is dict) or (type(new_json_data) is list):
                    item = find_key_and_replace_value_json(new_json_data, args_key, args_value)
                    if (item is not None) or (type(item) is str):
                        json.dumps(json_data, indent=2, sort_keys=True)
    new_json.append(json_data)
    return new_json


def edit_template_json(json_file_path, args_data):
    new_json = []
    json_file = json_file_path
    if type(args_data) is list:
        for index, item in enumerate(args_data):
            # Convert to dict
            args = eval(args_data[index])
            # Load json file
            with open(json_file, 'r') as file:
                data = json.load(file)
                # If .json starts with "[", Python will load as a list, so you need to convert it for to dict
                json_data = convert_to_dict(data)
                new_json_data = edit_json(json_data, args)
                new_json.append(json.dumps(new_json_data, sort_keys=True))
    if type(args_data) is dict:
        args = args_data
        with open(json_file, 'r') as file:
            data = json.load(file)
            # If .json starts with "[", Python will load as a list, so you need to convert it for to dict
            json_data = convert_to_dict(data)
            new_json = edit_json(json_data, args)
            new_json.append(json.dumps(new_json_data, sort_keys=True))
    return new_json


def create_payload(json_template_name, data, multiple_request):
    edited_json = template_editor(json_template_name, data, multiple_request)
    body = get_beautified_payload(json_template_name, edited_json)
    return body


def get_template_from_folder(folder_path, template_name):
    file_folder = jinja2.FileSystemLoader(searchpath=folder_path)
    template_env = jinja2.Environment(loader=file_folder)
    template = template_env.get_template(template_name)
    return template


def template_editor(json_template_name, data, multiple_request):
    if json_template_name != "None" and json_template_name != "none" and json_template_name is not None and data is not None:
        json_template = json_template_name + ".json"
        template = get_template_from_folder(os.path.join(os.getcwd(), "templates"), json_template)
        if multiple_request and type(data) is list:
            return [template.render(dict_list=[d]) for d in data]
        else:
            return template.render(dict_list=data)
    else:
        return data


def get_beautified_payload(json_template_name, payload):
    body_list = []
    if type(payload) is not list:
        body = payload.replace('\n', '').replace('"[', '[').replace(']"', ']').replace(
            '"{ ', '{').replace('}"', '}')
        return beautify_json(json_template_name, body)
    else:
        for body in payload:
            body_list.append(beautify_json(json_template_name, body))
        return body_list


def beautify_json(json_template_name, json_string):
    try:
        return json.dumps(json.loads(json_string), indent=4, ensure_ascii=False).encode('utf8')
    except json.decoder.JSONDecodeError as err:  # includes simplejson.decoder.JSONDecodeError
        body = json_string.replace('"[', '[').replace(']"', ']').replace(
            '"{ ', '{').replace('}"', '}').replace(' ', '')
        error_message = "JSON error decoding file: '{0}'".format(err)
        message = "Check if the template " + json_template_name + " is malformed. " \
                                                                  "Check the body request, fix your template file" \
                                                                  " and try again." \
                                                                  "\nError Message: " + error_message + \
                  "\nBODY REQUEST: " + body

        raise Exception(message)



__version__ = '0.0.3'
try:
    #from ._lazy_qa import longest  # noqa
    from csv_builder import *
    from database_mysql import *
    from database_postgresql import *
    from json_builder import *
    from list_manipulation import *
    from request_builder import *
    from string_manipulation import *
    from yaml_manipulation import *
except ImportError:
    def longest(args):
        return max(args, key=len)



import psycopg2

# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate Postgre Database                                       #
# ---------------------------------------------------------------------------------------------------------------------#

# -------------------------------------------------- CSV Functions ----------------------------------------------------#

# Update connection string information
host = "test_db.postgres.database.azure.com"
dbname = "test_db"
user = "postgresql_admin@test_db"
password = "password_x"
ssl_mode = "require"


def open_postgresql_connection(host, dbname, user, password, ssl_mode):
    # Construct connection string
    conn_string = "host={0} user={1} dbname={2} password={3} sslmode={4}".format(host, user, dbname, password, ssl_mode)
    conn = psycopg2.connect(conn_string)
    print("Connection established")
    return conn.cursor()


def connection_test():
    cursor = open_postgresql_connection(host, dbname, user, password, ssl_mode)
    # Fetch all rows from table
    cursor.execute("SELECT * FROM table limit 1;")
    print(cursor)
    rows = cursor.fetchall()

    # Print all rows
    for row in rows:
        print("Data row = %s" % (str(row)))
    cursor1 = open_postgresql_connection(host, dbname, user, password, ssl_mode)
    # Fetch all rows from table
    cursor1.execute("SELECT * FROM table limit 1;")
    print(cursor1)
    rows = cursor1.fetchall()
    # Print all rows
    for row in rows:
        print("Data row = %s" % (str(row)))



import string
import random

# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate API Requests                                           #
# ---------------------------------------------------------------------------------------------------------------------#

# --------------------------------------------- Random String Functions -----------------------------------------------#


def generate_unique_id(chars_number):
    """Generate N chars random string with Lowercase and Uppercase."""
    unique_id = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(chars_number)])
    return unique_id


def generate_unique_lowercase_id(chars_number):
    """Generate N chars random string with Lowercase."""
    unique_id = ''.join([random.choice(string.ascii_lowercase + string.digits) for n in range(chars_number)])
    return unique_id


def generate_unique_uppercase_id(chars_number):
    """Generate N chars random string with Uppercase."""
    unique_id = ''.join([random.choice(string.ascii_uppercase + string.digits) for n in range(chars_number)])
    return unique_id


def generate_unique_email(username, id, domain_list):
    """Generate random email, combine generate_unique_id,  generate_unique_lowercase_id or
    generate_unique_uppercase_id and a list of domains. """
    email = username + '.' + id + random.choice(domain_list)
    return email


# ---------------------------------------------  String Manipulation Functions ----------------------------------------#


def split_string_between(string_value, slice_a, slice_b):
    """Find and validate before-part and return middle part."""
    pos_a = string_value.find(slice_a)
    if pos_a == -1: return ""
    # Find and validate after part.
    pos_b = string_value.rfind(slice_b)
    if pos_b == -1: return ""
    # Return middle part.
    adjusted_pos_a = pos_a + len(slice_a)
    if adjusted_pos_a >= pos_b: return ""
    return string_value[adjusted_pos_a:pos_b]


def split_string_before(string_value, slice_a):
    """Find first part and return slice before it."""
    pos_a = string_value.find(slice_a)
    if pos_a == -1: return ""
    return string_value[0:pos_a]


def split_string_after(string_value, slice_a):
    """Find and validate first part and returns chars after the found string."""
    pos_a = string_value.rfind(slice_a)
    if pos_a == -1: return ""
    # Returns chars after the found string.
    adjusted_pos_a = pos_a + len(slice_a)
    if adjusted_pos_a >= len(string_value): return ""
    return string_value[adjusted_pos_a:]


def remove_chars_from_string(string_value, char_list):
    """Remove all characters in list from string."""
    new_string = string_value
    for char in char_list:
        # Remove the char in list from the string value.
        new_string = new_string.replace(char, "")
    return new_string


def replace_string_with(string_value, old_string, new_string):
    # Replace the string for another value.
    result_string = string_value.replace(old_string, new_string)
    return result_string


def empty_string_to_none_string(string_value):
    # Replace the string "" or '' for None.
    if string_value == '' or "":
        return None
    else:
        return string_value


def generate_random_number(number_of_digits):
    begin = int('1' + '0' * (number_of_digits - 1))
    end = int('9' * number_of_digits)
    return str(random.randrange(begin, end))



import json
import csv
import pandas as pd
import os


# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate CSV data files                                         #
# ---------------------------------------------------------------------------------------------------------------------#

# -------------------------------------------------- CSV Functions ----------------------------------------------------#


def delete_output_file(file_path):
    if os.path.exists(file_path):
        os.remove(file_path)


def load_csv(csv_file_path):
    new_json = []
    with open(csv_file_path, mode='r') as csv_file:
        csv_reader = csv.DictReader(csv_file)
        for row in csv_reader:
            new_json.append(json.dumps(row, sort_keys=True))
    return new_json


def load_csv_multiple_lines(csv_file, group_key, output_list_name, list_fields):
    result = {}
    with open(csv_file, 'r') as fh:
        csv_reader = csv.DictReader(fh)
        for row in csv_reader:
            group_key_joined = get_group_key(row, group_key)
            if group_key_joined not in result:
                result[group_key_joined] = row.copy()
                result[group_key_joined][output_list_name] = []
            result[group_key_joined][output_list_name].append({field: row[field] for field in list_fields})

    return [json.dumps(data) for data in result.values()]


def get_group_key(row, group_key):
    return "_".join(str(row[r]) for r in row if r in group_key)


def get_scenario_data_csv(csv_file_path, test_scenario_id):
    new_json = []
    with open(csv_file_path, mode='r') as csv_file:
        csv_reader = csv.DictReader(csv_file)
        for row in csv_reader:
            if test_scenario_id == row["test_scenario_id"]:
                new_json.append(json.dumps(row, sort_keys=True))
    return new_json


def get_each_line_data_csv(csv_file_path):
    new_json = []
    with open(csv_file_path, mode='r') as csv_file:
        csv_reader = csv.DictReader(csv_file)
        for row in csv_reader:
            new_json.append(json.dumps(row, sort_keys=True))
    return new_json


def converter_pandas_csv_json(data_path):
    df = pd.read_csv(data_path)
    new_json = df.to_json(orient='records')
    return new_json




import gzip
import time
import calendar
import io
import requests
import zlib

# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate API Requests                                           #
# ---------------------------------------------------------------------------------------------------------------------#

# ---------------------------------------------- API Requests Functions -----------------------------------------------#


def response_from_auth(method, url, payload):
    request_trace_id = "TestData-" + method
    headers = {
        'requestTraceId': request_trace_id,
        'Content-Type': 'application/x-www-form-urlencoded',

    }
    response = select_request(method, url, payload, headers)
    if method is not None:
        if response is not None:
            # evaluate_response(payload, response)
            data = response.json()
            return data
        else:
            print("Auth wasn't able to be execute through the method " + str(method) + ". Check your configuration yml "
                                                                                       "and try again.")


def get_access_token(key, method, url, payload):
    print("\nGetting Token Authentication...")
    data = response_from_auth(method, url, payload)
    if key in data:
        token = data[key]
        return str(token)


def zip_payload(payload: str) -> bytes:
    file = io.BytesIO()
    g = gzip.GzipFile(fileobj=file, mode='w')
    if type(payload) is str:
        g.write(bytes(payload, "utf-8"))
    else:
        g.write(payload)
    g.close()
    return file.getvalue()


def print_request_and_exit(method, url, headers, body_request, zip_payload_needed):
    # connection_test()
    print('\n\n*************************** DEBUG MODE ***************************')
    print('                No request made to any endpoint!!!')
    print('Add the -e flag to the command line to really execute the requests')
    print('********************************************************************\n')
    print(f'METHOD: {method}\n')
    print(f'URL: {url}\n')
    print(f'HEADERS: \n\n{headers}\n')
    if type(body_request) is not list:
        unzipped_payload = zlib.decompress(body_request, 16 + zlib.MAX_WBITS) if zip_payload_needed else body_request
        if type(unzipped_payload) is not bytes:
            unzipped_payload = bytearray(unzipped_payload, "utf-8")
        print(f'PAYLOAD: \n\n{unzipped_payload.decode("utf-8")}\n')
    else:
        for req in body_request:
            unzipped_payload = zlib.decompress(req, 16 + zlib.MAX_WBITS) if zip_payload_needed else req
            if type(unzipped_payload) is not bytes:
                unzipped_payload = bytearray(unzipped_payload, "utf-8")
            print(f'PAYLOAD: \n\n{unzipped_payload.decode("utf-8")}\n')


def split(list_a, chunk_size):
    for i in range(0, len(list_a), chunk_size):
        yield list_a[i:i + chunk_size]


def get_multiple_requests(method, url, headers, payload):
    response = []
    chunk_payload = split(payload, 1)
    for idx, e in enumerate(payload):
        if type(headers) is list:
            new_headers = headers[idx]
        else:
            new_headers = headers
        new_headers['requestTraceId'] = f"{new_headers['requestTraceId']}_part_{idx + 1}_of_{len(payload)}"
        new_headers['x-timestamp'] = str(calendar.timegm(time.gmtime()))
        response.append(requests.request(method, url, data=e, headers=new_headers))
    return response


def select_request(method, url, payload, headers, multiple_request=False):
    # This method is responsible for create only one body for method
    if method == "post":
        if multiple_request:
            response = get_multiple_requests(method, url, headers, payload)
        else:
            response = requests.post(url, data=payload, headers=headers, verify=False)
        return response
    elif method == "put":
        if multiple_request:
            response = get_multiple_requests(method, url, headers, payload)
        else:
            response = requests.put(url, data=payload, headers=headers, verify=False)
        return response
    elif method == "delete":
        if multiple_request:
            response = get_multiple_requests(method, url, headers, payload)
        else:
            response = requests.delete(url, data=payload, headers=headers, verify=False)
        return response
    elif method == "get":
        all_responses = []
        for p in payload:
            response = requests.get(url, headers=headers, params=p, verify=False)
            all_responses.append(response)
        return all_responses
    else:
        print("Method " + method + " is not found")
        return None  # 0 is the default case if method is not found



import random


# ---------------------------------------------------------------------------------------------------------------------#
#                                       Functions to manipulate List                                                   #
# ---------------------------------------------------------------------------------------------------------------------#

# -------------------------------------------------- List Functions ---------------------------------------------------#


def union_list_without_duplicate_item(list_a, list_b):
    result_list = list(list_a)
    result_list.extend(x for x in list_b if x not in result_list)


def intersection_list(list_a, list_b):
    result_list = [list(filter(lambda x: x in list_a, sublist)) for sublist in list_b]
    return result_list


def remove_item_from_list(list, item):
    result_list = list.remove(item)
    return result_list


def get_random_item_from_list(list, item):
    selected_item = random.choice(list)
    return selected_item


def get_different_random_item_from_list(list, item):
    result_list = list.remove(item)
    selected_item = random.choice(result_list)
    return selected_item


# -----------------------------------------------------------------------------------------------------------------#
# GET_LIST_FROM_SOURCE is a function use to load a data from a source archive. It's useful to get all information  #
# from a collection. For example, if you need to POST the same .json and the data don't need to be changed, the    #
# data source can emulate the .json.                                                                               #
# This function needs 2 arguments: the dict's name and the collection's name:                                      #
#   Example:                                                                                                       #
#       DATA_SOURCE ={                     payload = get_list_from_source(DATA_SOURCE, 'valid_data')               #
# 	        "valid_data" :[{               print("Payload is: ", payload)                                          #
# 	                 "key_1" : "value1",                                                                           #
#      	             "key_2" : "value2"                                                                            #
#      	     }],                           output:  Payload is:   "valid_data" :[{                                 #
#           "invalid_data" :[{                                           "key_1" : "value1",                       #
# 	                "key_1" : "value1",                                  "key_2" : "value2"                        #
#      	            "key_2" : "value2"                                   }]                                        #
#      	            }]                                                                                             #
# }                                                                                                                #                                                                          #
# -----------------------------------------------------------------------------------------------------------------#


def get_list_from_source(source, data):
    """Get a list of arguments named as 'data' on the 'source'."""
    data_args = source.get(data.replace(' ', '_'))
    if data_args is not None:
        # Return the list if not Empty
        return data_args[0]
    else:
        message = "No matching results for parameter data = " + data + " was found in DataPool."
        raise Exception(message)


# -----------------------------------------------------------------------------------------------------------------#
# DATAPOOL_READ is a function use to get a collection of information from a source archive Dictionaries, Hashmaps, #
# and Hash Tables.                                                                                                 #
# This function needs 3 arguments: the dict's name, the collection's name and the key that you searching for.      #
#                                                                                                                  #
#   Example:                                  result = datapool_read(DATA_SOURCE, valid_data, 'key_1')             #
#       DATA_SOURCE ={                        print("Results is: ", result)                                        #
# 	        "valid_data" :[{                                                                                       #
# 	                 "key_1" : "value1",                                                                           #
#      	             "key_2" : "value2"       output:  Results is: value1                                          #
#      	     }],                                                                                                   #
#           "invalid_data" :[{                                                                                     #
# 	                "key_1" : "value1",                                                                            #
#      	            "key_2" : "value2"                                                                             #
#      	            }]                                                                                             #
# }                                                                                                                #                                                                          #
# -----------------------------------------------------------------------------------------------------------------#


def datapool_read(source, data, key):
    """Get a list of arguments named as 'data' on the 'source' and search the 'key' on that list."""
    data_args = source.get(data.replace(' ', '_'))
    dt_key = key.replace(' ', '_')
    if data_args is not None:
        # Search the 'key' on that list ------> for "python data_args[0].get(dt_key)"
        if data_args.get(dt_key) is not None:
            return data_args.get(dt_key)
        else:
            message = "No matching results for parameter data = " + data + " on the key = " + key + "was found in " \
                                                                                                    "DataPool. "
            raise Exception(message)
    else:
        message = "No matching results for parameter data = " + data + " on the key = " + key + "was found in " \
                                                                                                "DataPool. "
        raise Exception(message)


def get_data_from_dict(dict_args, key):
    """Get a dictionary of arguments named as 'dict_args', search the 'key' on that dict and return the value."""
    data_args = dict_args
    if data_args is not None:
        # Search the 'key' on that list
        if data_args.get(key) is not None:
            return data_args.get(key)
    else:
        message = "No matching results for parameter key = " + key + " was found in Dictionary."
        raise Exception(message)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-

import io
import os
import platform
import re
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import relpath
from os.path import splitext

from setuptools import Extension
from setuptools import find_packages
from setuptools import setup
from setuptools.command.build_ext import build_ext
from setuptools.dist import Distribution

# Enable code coverage for C code: we can't use CFLAGS=-coverage in tox.ini, since that may mess with compiling
# dependencies (e.g. numpy). Therefore we set SETUPPY_CFLAGS=-coverage in tox.ini and copy it to CFLAGS here (after
# deps have been safely installed).
if 'TOX_ENV_NAME' in os.environ and os.environ.get('SETUPPY_EXT_COVERAGE') == 'yes' and platform.system() == 'Linux':
    CFLAGS = os.environ['CFLAGS'] = '-fprofile-arcs -ftest-coverage'
    LFLAGS = os.environ['LFLAGS'] = '-lgcov'
else:
    CFLAGS = ''
    LFLAGS = ''


class OptionalBuildExt(build_ext):
    """Allow the building of C extensions to fail."""
    def run(self):
        try:
            if os.environ.get('SETUPPY_FORCE_PURE'):
                raise Exception('C extensions disabled (SETUPPY_FORCE_PURE)!')
            super().run()
        except Exception as e:
            self._unavailable(e)
            self.extensions = []  # avoid copying missing files (it would fail).

    def _unavailable(self, e):
        print('*' * 80)
        print('''WARNING:

    An optional code optimization (C extension) could not be compiled.

    Optimizations for this package will not be available!
        ''')

        print('CAUSE:')
        print('')
        print('    ' + repr(e))
        print('*' * 80)


class BinaryDistribution(Distribution):
    """Distribution which almost always forces a binary package with platform name"""
    def has_ext_modules(self):
        return super().has_ext_modules() or not os.environ.get('SETUPPY_ALLOW_PURE')


def read(*names, **kwargs):
    with io.open(join(dirname(__file__), *names), encoding=kwargs.get('encoding', 'utf8')) as fh:
        return fh.read()


setup(
    name='lazy-qa',
    use_scm_version={
        'local_scheme': 'dirty-tag',
        'write_to': 'src/lazy_qa/_version.py',
        'fallback_version': '0.0.3',
    },
    license='MIT',
    description='  ',
    long_description='{}\n{}'.format(
        re.compile('^.. start-badges.*^.. end-badges', re.M | re.S).sub('', read('README.rst')),
        re.sub(':[a-z]+:`~?(.*?)`', r'``\1``', read('CHANGELOG.rst')),
    ),
    author='Priscilla Rodrigues Martins',
    author_email='angeleyes.ffx@hotmail.com',
    url='https://github.com/angeleyesffx/lazy_qa',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        # uncomment if you test on these interpreters:
        # 'Programming Language :: Python :: Implementation :: IronPython',
        # 'Programming Language :: Python :: Implementation :: Jython',
        # 'Programming Language :: Python :: Implementation :: Stackless',
        'Topic :: Utilities',
    ],
    project_urls={
        'Documentation': 'https://lazy_qa.readthedocs.io/',
        'Changelog': 'https://lazy_qa.readthedocs.io/en/latest/changelog.html',
        'Issue Tracker': 'https://github.com/angeleyesffx/lazy_qa/issues',
    },
    keywords=[
        # eg: 'keyword1', 'keyword2', 'keyword3',
    ],
    python_requires='>=3.6',
    install_requires=[
        # eg: 'aspectlib==1.1.1', 'six>=1.7',
    ],
    extras_require={
        # eg:
        #   'rst': ['docutils>=0.11'],
        #   ':python_version=="2.6"': ['argparse'],
    },
    setup_requires=[
        'pytest-runner',
        'setuptools_scm>=3.3.1',
    ],
    entry_points={
        'console_scripts': [
            'lazy-qa = lazy_qa.cli:main',
        ]
    },
    cmdclass={'build_ext': OptionalBuildExt},
    ext_modules=[
        Extension(
            splitext(relpath(path, 'src').replace(os.sep, '.'))[0],
            sources=[path],
            extra_compile_args=CFLAGS.split(),
            extra_link_args=LFLAGS.split(),
            include_dirs=[dirname(path)]
        )
        for root, _, _ in os.walk('src')
        for path in glob(join(root, '*.c'))
    ],
    distclass=BinaryDistribution,
)
